@@ -258,9 +258,6 @@ public class DataSourceProxy implements PoolConfiguration {
 //      PROPERTIES WHEN NOT USED WITH FACTORY
 /*------------------------------------------------------------------------*/
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getPoolName() {
@@ -272,99 +269,66 @@ public class DataSourceProxy implements PoolConfiguration {
         this.poolProperties = poolProperties;
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDriverClassName(String driverClassName) {
         this.poolProperties.setDriverClassName(driverClassName);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setInitialSize(int initialSize) {
         this.poolProperties.setInitialSize(initialSize);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setInitSQL(String initSQL) {
         this.poolProperties.setInitSQL(initSQL);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setLogAbandoned(boolean logAbandoned) {
         this.poolProperties.setLogAbandoned(logAbandoned);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMaxActive(int maxActive) {
         this.poolProperties.setMaxActive(maxActive);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMaxIdle(int maxIdle) {
         this.poolProperties.setMaxIdle(maxIdle);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMaxWait(int maxWait) {
         this.poolProperties.setMaxWait(maxWait);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMinEvictableIdleTimeMillis(int minEvictableIdleTimeMillis) {
         this.poolProperties.setMinEvictableIdleTimeMillis(minEvictableIdleTimeMillis);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMinIdle(int minIdle) {
         this.poolProperties.setMinIdle(minIdle);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setNumTestsPerEvictionRun(int numTestsPerEvictionRun) {
         this.poolProperties.setNumTestsPerEvictionRun(numTestsPerEvictionRun);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setPassword(String password) {
@@ -372,81 +336,54 @@ public class DataSourceProxy implements PoolConfiguration {
         this.poolProperties.getDbProperties().setProperty("password",this.poolProperties.getPassword());
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setRemoveAbandoned(boolean removeAbandoned) {
         this.poolProperties.setRemoveAbandoned(removeAbandoned);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setRemoveAbandonedTimeout(int removeAbandonedTimeout) {
         this.poolProperties.setRemoveAbandonedTimeout(removeAbandonedTimeout);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setTestOnBorrow(boolean testOnBorrow) {
         this.poolProperties.setTestOnBorrow(testOnBorrow);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setTestOnConnect(boolean testOnConnect) {
         this.poolProperties.setTestOnConnect(testOnConnect);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setTestOnReturn(boolean testOnReturn) {
         this.poolProperties.setTestOnReturn(testOnReturn);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setTestWhileIdle(boolean testWhileIdle) {
         this.poolProperties.setTestWhileIdle(testWhileIdle);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setTimeBetweenEvictionRunsMillis(int timeBetweenEvictionRunsMillis) {
         this.poolProperties.setTimeBetweenEvictionRunsMillis(timeBetweenEvictionRunsMillis);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setUrl(String url) {
         this.poolProperties.setUrl(url);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setUsername(String username) {
@@ -454,114 +391,77 @@ public class DataSourceProxy implements PoolConfiguration {
         this.poolProperties.getDbProperties().setProperty("user",getPoolProperties().getUsername());
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setValidationInterval(long validationInterval) {
         this.poolProperties.setValidationInterval(validationInterval);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setValidationQuery(String validationQuery) {
         this.poolProperties.setValidationQuery(validationQuery);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setValidatorClassName(String className) {
         this.poolProperties.setValidatorClassName(className);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setValidationQueryTimeout(int validationQueryTimeout) {
         this.poolProperties.setValidationQueryTimeout(validationQueryTimeout);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setJdbcInterceptors(String interceptors) {
         this.getPoolProperties().setJdbcInterceptors(interceptors);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setJmxEnabled(boolean enabled) {
         this.getPoolProperties().setJmxEnabled(enabled);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setFairQueue(boolean fairQueue) {
         this.getPoolProperties().setFairQueue(fairQueue);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setUseLock(boolean useLock) {
         this.getPoolProperties().setUseLock(useLock);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDefaultCatalog(String catalog) {
         this.getPoolProperties().setDefaultCatalog(catalog);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDefaultAutoCommit(Boolean autocommit) {
         this.getPoolProperties().setDefaultAutoCommit(autocommit);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDefaultTransactionIsolation(int defaultTransactionIsolation) {
         this.getPoolProperties().setDefaultTransactionIsolation(defaultTransactionIsolation);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setConnectionProperties(String properties) {
         try {
-            java.util.Properties prop = DataSourceFactory
-                    .getProperties(properties);
+            Properties prop = DataSourceFactory.getProperties(properties);
             Iterator<?> i = prop.keySet().iterator();
             while (i.hasNext()) {
                 String key = (String) i.next();
@@ -575,9 +475,6 @@ public class DataSourceProxy implements PoolConfiguration {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setUseEquals(boolean useEquals) {
@@ -642,18 +539,12 @@ public class DataSourceProxy implements PoolConfiguration {
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getSuspectTimeout() {
         return getPoolProperties().getSuspectTimeout();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setSuspectTimeout(int seconds) {
@@ -857,45 +748,30 @@ public class DataSourceProxy implements PoolConfiguration {
     //  PROPERTIES / CONFIGURATION
     //=========================================================
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getConnectionProperties() {
         return getPoolProperties().getConnectionProperties();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Properties getDbProperties() {
         return getPoolProperties().getDbProperties();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getDefaultCatalog() {
         return getPoolProperties().getDefaultCatalog();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getDefaultTransactionIsolation() {
         return getPoolProperties().getDefaultTransactionIsolation();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getDriverClassName() {
@@ -903,99 +779,66 @@ public class DataSourceProxy implements PoolConfiguration {
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getInitialSize() {
         return getPoolProperties().getInitialSize();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getInitSQL() {
         return getPoolProperties().getInitSQL();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getJdbcInterceptors() {
         return getPoolProperties().getJdbcInterceptors();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getMaxActive() {
         return getPoolProperties().getMaxActive();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getMaxIdle() {
         return getPoolProperties().getMaxIdle();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getMaxWait() {
         return getPoolProperties().getMaxWait();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getMinEvictableIdleTimeMillis() {
         return getPoolProperties().getMinEvictableIdleTimeMillis();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getMinIdle() {
         return getPoolProperties().getMinIdle();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public long getMaxAge() {
         return getPoolProperties().getMaxAge();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getName() {
         return getPoolProperties().getName();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getNumTestsPerEvictionRun() {
@@ -1010,9 +853,6 @@ public class DataSourceProxy implements PoolConfiguration {
         return "Password not available as DataSource/JMX operation.";
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getRemoveAbandonedTimeout() {
@@ -1020,180 +860,120 @@ public class DataSourceProxy implements PoolConfiguration {
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getTimeBetweenEvictionRunsMillis() {
         return getPoolProperties().getTimeBetweenEvictionRunsMillis();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getUrl() {
         return getPoolProperties().getUrl();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getUsername() {
         return getPoolProperties().getUsername();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public long getValidationInterval() {
         return getPoolProperties().getValidationInterval();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getValidationQuery() {
         return getPoolProperties().getValidationQuery();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getValidationQueryTimeout() {
         return getPoolProperties().getValidationQueryTimeout();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public String getValidatorClassName() {
         return getPoolProperties().getValidatorClassName();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Validator getValidator() {
         return getPoolProperties().getValidator();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setValidator(Validator validator) {
         getPoolProperties().setValidator(validator);
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isAccessToUnderlyingConnectionAllowed() {
         return getPoolProperties().isAccessToUnderlyingConnectionAllowed();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Boolean isDefaultAutoCommit() {
         return getPoolProperties().isDefaultAutoCommit();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Boolean isDefaultReadOnly() {
         return getPoolProperties().isDefaultReadOnly();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isLogAbandoned() {
         return getPoolProperties().isLogAbandoned();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isPoolSweeperEnabled() {
         return getPoolProperties().isPoolSweeperEnabled();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isRemoveAbandoned() {
         return getPoolProperties().isRemoveAbandoned();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public int getAbandonWhenPercentageFull() {
         return getPoolProperties().getAbandonWhenPercentageFull();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isTestOnBorrow() {
         return getPoolProperties().isTestOnBorrow();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isTestOnConnect() {
         return getPoolProperties().isTestOnConnect();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isTestOnReturn() {
         return getPoolProperties().isTestOnReturn();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isTestWhileIdle() {
@@ -1201,279 +981,180 @@ public class DataSourceProxy implements PoolConfiguration {
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Boolean getDefaultAutoCommit() {
         return getPoolProperties().getDefaultAutoCommit();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public Boolean getDefaultReadOnly() {
         return getPoolProperties().getDefaultReadOnly();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public InterceptorDefinition[] getJdbcInterceptorsAsArray() {
         return getPoolProperties().getJdbcInterceptorsAsArray();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean getUseLock() {
         return getPoolProperties().getUseLock();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isFairQueue() {
         return getPoolProperties().isFairQueue();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isJmxEnabled() {
         return getPoolProperties().isJmxEnabled();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public boolean isUseEquals() {
         return getPoolProperties().isUseEquals();
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setAbandonWhenPercentageFull(int percentage) {
         getPoolProperties().setAbandonWhenPercentageFull(percentage);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setAccessToUnderlyingConnectionAllowed(boolean accessToUnderlyingConnectionAllowed) {
         getPoolProperties().setAccessToUnderlyingConnectionAllowed(accessToUnderlyingConnectionAllowed);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDbProperties(Properties dbProperties) {
         getPoolProperties().setDbProperties(dbProperties);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setDefaultReadOnly(Boolean defaultReadOnly) {
         getPoolProperties().setDefaultReadOnly(defaultReadOnly);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setMaxAge(long maxAge) {
         getPoolProperties().setMaxAge(maxAge);
     }
 
-    /**
-     * {@inheritDoc}
-     */
 
     @Override
     public void setName(String name) {
         getPoolProperties().setName(name);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setDataSource(Object ds) {
         getPoolProperties().setDataSource(ds);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public Object getDataSource() {
         return getPoolProperties().getDataSource();
     }
 
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setDataSourceJNDI(String jndiDS) {
         getPoolProperties().setDataSourceJNDI(jndiDS);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public String getDataSourceJNDI() {
         return getPoolProperties().getDataSourceJNDI();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean isAlternateUsernameAllowed() {
         return getPoolProperties().isAlternateUsernameAllowed();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setAlternateUsernameAllowed(boolean alternateUsernameAllowed) {
         getPoolProperties().setAlternateUsernameAllowed(alternateUsernameAllowed);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setCommitOnReturn(boolean commitOnReturn) {
         getPoolProperties().setCommitOnReturn(commitOnReturn);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getCommitOnReturn() {
         return getPoolProperties().getCommitOnReturn();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setRollbackOnReturn(boolean rollbackOnReturn) {
         getPoolProperties().setRollbackOnReturn(rollbackOnReturn);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getRollbackOnReturn() {
         return getPoolProperties().getRollbackOnReturn();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setUseDisposableConnectionFacade(boolean useDisposableConnectionFacade) {
         getPoolProperties().setUseDisposableConnectionFacade(useDisposableConnectionFacade);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getUseDisposableConnectionFacade() {
         return getPoolProperties().getUseDisposableConnectionFacade();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setLogValidationErrors(boolean logValidationErrors) {
         getPoolProperties().setLogValidationErrors(logValidationErrors);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getLogValidationErrors() {
         return getPoolProperties().getLogValidationErrors();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getPropagateInterruptState() {
         return getPoolProperties().getPropagateInterruptState();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setPropagateInterruptState(boolean propagateInterruptState) {
         getPoolProperties().setPropagateInterruptState(propagateInterruptState);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean isIgnoreExceptionOnPreLoad() {
         return getPoolProperties().isIgnoreExceptionOnPreLoad();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setIgnoreExceptionOnPreLoad(boolean ignoreExceptionOnPreLoad) {
         getPoolProperties().setIgnoreExceptionOnPreLoad(ignoreExceptionOnPreLoad);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public boolean getUseStatementFacade() {
         return getPoolProperties().getUseStatementFacade();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public void setUseStatementFacade(boolean useStatementFacade) {
         getPoolProperties().setUseStatementFacade(useStatementFacade);
